@@ -1,4 +1,4 @@
-# Copyright (C) 2017  Ruby-GNOME Project Team
+# Copyright (C) 2021  Ruby-GNOME Project Team
 #
 # This library is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -20,12 +20,13 @@ class NativePackageInstaller
 
       class << self
         def current_platform?
-          File.exist?("/etc/fedora-release")
+          os_release = OSRelease.new
+          os_release.id == "fedora"
         end
       end
 
       def package(spec)
-        spec[:fedora] || spec[:redhat]
+        spec[:fedora] || spec[:rhel] || spec[:redhat]
       end
 
       def install_command
